.. automodule:: elpigraph

API
===

Import the package as::

   import elpigraph

Principal graphs
----------------

.. autosummary::
   :toctree: .

   computeElasticPrincipalCurve
   computeElasticPrincipalCIrcle
   computeElasticPrincipalTree

Plotting
--------

.. autosummary::
   :toctree: .

   plot.PlotPG